/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    31-October-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/

#include <stdio.h>
#include "main.h"


/* Exported functions ---------------------------------------------------------*/
extern  uint8_t CAN_Send(CAN_TypeDef *CAN,CanTxMsg *Message);

/* Global Variables ---------------------------------------------------------*/
xQueueHandle xQueueCAN2,xQueueCAN1,xQueueSendArray;

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/*--------------- Tasks Priority -------------*/

#define TASK_PRIO    ( tskIDLE_PRIORITY + 1 )

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
static uint8_t array_send[2000]={1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20};


/* Private function prototypes -----------------------------------------------*/
static void LED_Init(void);

/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Polls for the button and starts the ArraySend task
  * @param  pvParameters not used
  * @retval None
  */
void vTask_LEDApli(void * pvParameters)
{
	volatile uint8_t buttonstate=0,i=0, old_button=0;

	/*Create queue*/
    xQueueSendArray = xQueueCreate( 1, sizeof( uint8_t ) );

    /*Queue successful created*/
    if( xQueueSendArray == 0 )
    {
    	while(1)
    	;
    }

for( ;; )
 {
	/*Check if Button is pressed*/
    if(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0) && old_button == 0)
    {
    	/*Put the Button state into the Queue to unblock it*/
    	xQueueSendToFront( xQueueSendArray, &buttonstate, 0 );

    }

    old_button=GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0);

    vTaskDelay(200);
}
}
/**
  * @brief  CAN1 sends Array and toggles LED orange
  * @param  pvParameters not used
  * @retval None
  */
void vTask_ArraySend(void * pvParameters)
{
	uint16_t i,j;
    CanTxMsg Message;
    static uint8_t buttonstate=0;
    uint8_t transmitstatus=0;


      for( ;; )
      {


    	/* toggle LED each 250ms */
    	GPIO_ToggleBits(GPIOD, GPIO_Pin_13);

    	/*wait till everything is sent*/
    	vTaskDelay(10);

      }

}

/**
  * @brief  Resets the red LED
  * @param  pvParameters not used
  * @retval None
  */
void vTask_LEDReset(void * pvParameters)
{

      for( ;; )
      {

    	vTaskDelay(100);

    	GPIO_ResetBits(GPIOD, GPIO_Pin_13);

        vTaskDelay(100);

      }

}



/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
	uint16_t i;

	SystemInit();

  /*!< At this stage the microcontroller clock setting is already configured to
       168 MHz, this is done through SystemInit() function which is called from
       startup file (startup_stm32f4xx.s) before to branch to application main.
       To reconfigure the default setting of SystemInit() function, refer to
       system_stm32f4xx.c file
     */

  /*Initialize Leds */
  LED_Init();

  /*Configure the Interrupt*/
  InterruptCAN_Init();

  CAN_Initialisierung();

  for(i=0;i<2000;i++)
  {
	  array_send[i]=i;
  }

  /* Create Tasks */
  xTaskCreate( vTask_LEDApli, NULL, 1024, NULL, TASK_PRIO, NULL);
  xTaskCreate( vTask_ArraySend, NULL, 1024, NULL, TASK_PRIO, NULL);
  xTaskCreate( vTask_LEDReset, NULL, 1024, NULL, TASK_PRIO, NULL);

  /* Start scheduler */
  vTaskStartScheduler();

  /* We should never get here as control is now taken by the scheduler */
  for( ;; );
}



/**
  * @brief  Initializes the LEDs resources.
  * @param  None
  * @retval None
  */
void LED_Init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

  /* Initialize Discovery's LEDs */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE);

  /* Configure PD15 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_12|GPIO_Pin_13|  GPIO_Pin_14;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOD, &GPIO_InitStructure);

  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA, ENABLE);

  /* Configure PA0 input pulldown mode*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_DOWN;

  GPIO_Init(GPIOA, &GPIO_InitStructure);

}






/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
